;;; j-article.el - Special code for j-article style.

;; $Id: j-article.el,v 1.4 2003/02/20 16:35:46 oub Exp $

;;; Code:

(TeX-add-style-hook "j-article"
 (function (lambda ()
  (setq LaTeX-largest-level (LaTeX-section-level "section")))))

;;; j-article.el ends here
