;;; jarticle.el - Special code for jarticle style.

;; $Id: jarticle.el,v 1.4 2003/02/20 16:35:46 oub Exp $

;;; Code:

(TeX-add-style-hook "jarticle"
 (function (lambda () (setq LaTeX-largest-level 2))))

;;; jarticle.el ends here
