;;; j-book.el - Special code for j-book style.

;; $Id: j-book.el,v 1.4 2003/02/20 16:35:46 oub Exp $

;;; Code:

(TeX-add-style-hook "j-book"
 (function (lambda () (setq LaTeX-largest-level
			    (LaTeX-section-level "chapter")))))

;;; j-book.el ends here
