;;; report.el - Special code for report style.

;; $Id: report.el,v 1.4 2003/02/20 16:35:47 oub Exp $

;;; Code:

(TeX-add-style-hook "report"
 (function (lambda () 
  (setq LaTeX-largest-level (LaTeX-section-level "chapter")))))

;;; report.el ends here
