;;; article.el - Special code for article style.

;; $Id: article.el,v 1.4 2003/02/20 16:35:46 oub Exp $

;;; Code:

(TeX-add-style-hook "article"
 (function (lambda ()
  (setq LaTeX-largest-level (LaTeX-section-level "section")))))

;;; article.el ends here
