;;; danish.el - Setup AUC TeX for editing Danish text.

;; $Id: danish.el,v 1.4 2003/02/20 16:35:46 oub Exp $

;;; Code:

(TeX-add-style-hook "danish"
 (function (lambda ()
   (make-local-variable 'TeX-open-quote)
   (make-local-variable 'TeX-close-quote)
   (setq TeX-open-quote "\"`")
   (setq TeX-close-quote "\"'")
   (run-hooks 'TeX-language-dk-hook))))

;;; danish.el ends here
